==> gnumeric-0.55.tar.gz: gnumeric-0.55/plugins/guile/functions.scm <==
;; Guile Plugin Functions

;; Originally coded by Mark Probst

;; Modified by Ariel Rios
;; jarios@usa.net
;; Licensed under GPL
;; December 1999

;;sign function 
;;Usage: =SIGN(number)
;;returns -1, 0 or 1.

;(define (sign num)
;  (cond ((negative? num) -1)
;	((zero? num) 0)
;	(else 1)))



;(register-function
; "sign" "f"
; "@FUNCTION=SIGN
;@SYNTAX=SIGN(number)
;@DESCRIPTION=Returns -1 if NUMBER is less than 0, 1 if NUMBER
;is greater than 0 and 0 if NUMBER is equal 0."
;"Guile"
; sign)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;lcm function
;;Usage: =LCM(num, num)
;;returns the least common multiplier of N1 and N2
;;Please note that there is not lcm definition here
;;for it's defined on R4RS

;(register-function
; "lcm" "ff"
; "@FUNCTION=LCM
;@SYNTAX=LCM(n1,n2)
;@DESCRIPTION=Returns the least common multiplier of N1 and N2."
;"Guile"
; lcm)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;gcd function
;;Usage: =GCD(num, num)

;(register-function
; "gcd" "ff"
; "@FUNCTION=GCD
;@SYNTAX=GCD(n1,n2)
;@DESCRIPTION=Returns the greatest common divisor of N1 and N2."
;"Guile"
; gcd)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;fibonacci function
;;Usage: =FIBO(number)
;;Calculates the fibonacci number of number.
;;This function shows GP problem in handling great numbers
;;Until I arrange this the scheme functions checks whether
;;the function is bigger than 2 ^ 32
;;if so it returns a string.

(define (fibo n)
  (letrec ((fibof
            (lambda (n a b)
             (if (<= n 2)
                 b
                 (fibof (- n 1) b (+ a b))))))

    (fibof n 1 1)))



(register-function 
"fibo" "f"
"@FUNCTION=FIBO
@SYNTAX=FIBO(num)
@DESCRIPTION=Returns the fibonnacci computation for number."
"Guile"
fibo)

;;;;;;;;;;;;proof

;(define (test n)
;  1)

;(register-function
;"test" "a"
;"@FUNCTION=TEST
;@SYNTAX=TEST(num)
;@DESCRIPTION=test"
;test)

==> gnumeric-0.57.tar.gz: gnumeric-0.57/plugins/guile/functions.scm <==
;; Guile Plugin Functions

;; Originally coded by Mark Probst

;; Modified by Ariel Rios
;; jarios@usa.net
;; Licensed under GPL
;; December 1999

;;sign function 
;;Usage: =SIGN(number)
;;returns -1, 0 or 1.

;(define (sign num)
;  (cond ((negative? num) -1)
;	((zero? num) 0)
;	(else 1)))



;(register-function
; "sign" "f"
; "@FUNCTION=SIGN
;@SYNTAX=SIGN(number)
;@DESCRIPTION=Returns -1 if NUMBER is less than 0, 1 if NUMBER
;is greater than 0 and 0 if NUMBER is equal 0."
;"Guile"
; sign)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;lcm function
;;Usage: =LCM(num, num)
;;returns the least common multiplier of N1 and N2
;;Please note that there is not lcm definition here
;;for it's defined on R4RS

;(register-function
; "lcm" "ff"
; "@FUNCTION=LCM
;@SYNTAX=LCM(n1,n2)
;@DESCRIPTION=Returns the least common multiplier of N1 and N2."
;"Guile"
; lcm)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;gcd function
;;Usage: =GCD(num, num)

;(register-function
; "gcd" "ff"
; "@FUNCTION=GCD
;@SYNTAX=GCD(n1,n2)
;@DESCRIPTION=Returns the greatest common divisor of N1 and N2."
;"Guile"
; gcd)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;fibonacci function
;;Usage: =FIBO(number)
;;Calculates the fibonacci number of number.
;;This function shows GP problem in handling great numbers
;;Until I arrange this the scheme functions checks whether
;;the function is bigger than 2 ^ 32
;;if so it returns a string.

(define (fibo n)
  (letrec ((fibof
            (lambda (n a b)
             (if (<= n 2)
                 b
                 (fibof (- n 1) b (+ a b))))))

    (fibof n 1 1)))



(register-function 
"fibo" "f"
"@FUNCTION=FIBO
@SYNTAX=FIBO(num)
@DESCRIPTION=Returns the fibonnacci computation for number."
"Guile"
fibo)

;;;;;;;;;;;;proof

;(define (test n)
;  1)

;(register-function
;"test" "a"
;"@FUNCTION=TEST
;@SYNTAX=TEST(num)
;@DESCRIPTION=test"
;test)

;; Guile-gtk example use with care!

;(use-modules (gtk gtk))  
                  
;(define (ggtest n)
;(call-with-current-continuation
; (lambda(val)
; (let ((window (gtk-window-new 'toplevel))
;       (calendar (gtk-calendar-new)))
; (gtk-container-add window calendar)
; (gtk-widget-show-all window)
; (gtk-standalone-main window)

;(break n)))))


;(register-function
;"ggtest" "f"
;"@FUNCTION=GGTEST
;@SYNTAX=GGTEST(num)
;@DESCRIPTION=Guile-gtk test"
;"Guile"
;ggtest)
